==> contentsquare-1.0.1.tar.gz: example/simple_app/lib/src/screens/api_tests/widgets/webview/webview_screen.dart <==
import 'package:contentsquare_example/src/widgets/app_bar.dart';
import 'package:flutter/material.dart';

import '../../../../utils/navigate_and_monitor.dart';
import 'webviews/flutter/flutter_tracked_webview_screen.dart';
import 'webviews/fully/fully_tracked_webview_screen.dart';
import 'webviews/js/js_tracked_webview_screen.dart';
import 'webviews/untracked/untracked_webview_screen.dart';

class WebViewScreen extends StatelessWidget {
  const WebViewScreen({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Material(
      child: Scaffold(
        appBar: appBar(title: 'WebViews'),
        body: Padding(
          padding: const EdgeInsets.only(top: 30.0),
          child: Column(
            children: [
              Padding(
                padding: EdgeInsets.symmetric(horizontal: 16),
                child: Text(
                  'Select which type of web view you want to test',
                  style: Theme.of(context).textTheme.headline6,
                ),
              ),
              SizedBox(height: 20),
              ListTile(
                title: Text('Fully Tracked WebView'),
                onTap: () => navigateAndMonitor(
                  context,
                  FullyTrackedWebViewScreen(),
                ),
              ),
              SizedBox(height: 10),
              ListTile(
                title: Text('Partially Tracked WebView (Flutter side only)'),
                onTap: () => navigateAndMonitor(
                  context,
                  FlutterTrackedWebViewScreen(),
                ),
              ),
              SizedBox(height: 10),
              ListTile(
                title: Text('Partially Tracked WebView (Javascript side only)'),
                onTap: () => navigateAndMonitor(
                  context,
                  JSTrackedWebViewScreen(),
                ),
              ),
              SizedBox(height: 10),
              ListTile(
                title: Text('Untracked WebView'),
                onTap: () => navigateAndMonitor(
                  context,
                  UntrackedWebViewScreen(),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> contentsquare-1.3.2.tar.gz: example/simple_app/lib/src/screens/api_tests/widgets/webview/webview_screen.dart <==
import 'package:contentsquare_example/src/widgets/app_bar.dart';
import 'package:flutter/material.dart';

import '../../../../utils/navigate_and_monitor.dart';
import 'webviews/flutter/flutter_tracked_webview_screen.dart';
import 'webviews/fully/tracked_flutter_webview_screen.dart';
import 'webviews/fully/tracked_in_app_webview_creen.dart';
import 'webviews/js/js_tracked_webview_screen.dart';
import 'webviews/untracked/untracked_webview_screen.dart';

class WebViewScreen extends StatelessWidget {
  const WebViewScreen({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Material(
      child: Scaffold(
        appBar: appBar(title: 'WebViews'),
        body: Padding(
          padding: const EdgeInsets.only(top: 30.0),
          child: Column(
            children: [
              Padding(
                padding: EdgeInsets.symmetric(horizontal: 16),
                child: Text(
                  'Select which type of web view you want to test',
                  style: Theme.of(context).textTheme.headline6,
                ),
              ),
              SizedBox(height: 20),
              ListTile(
                title: Text('Fully Tracked WebView (flutter_webview)'),
                onTap: () => navigateAndMonitor(
                  context,
                  FullyTrackedFlutterWebViewScreen(),
                ),
              ),
              ListTile(
                title: Text('Fully Tracked WebView (flutter_inappwebview)'),
                onTap: () => navigateAndMonitor(
                  context,
                  FullyTrackedInAppWebViewScreen(),
                ),
              ),
              SizedBox(height: 10),
              ListTile(
                title: Text('Partially Tracked WebView (Flutter side only)'),
                onTap: () => navigateAndMonitor(
                  context,
                  FlutterTrackedWebViewScreen(),
                ),
              ),
              SizedBox(height: 10),
              ListTile(
                title: Text('Partially Tracked WebView (Javascript side only)'),
                onTap: () => navigateAndMonitor(
                  context,
                  JSTrackedWebViewScreen(),
                ),
              ),
              SizedBox(height: 10),
              ListTile(
                title: Text('Untracked WebView'),
                onTap: () => navigateAndMonitor(
                  context,
                  UntrackedWebViewScreen(),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
